@@ -58,7 +58,6 @@ public:
         MayOnlyBeSecretKeyIfOwnerTrustIsNotYetUltimate = 0x0040, // for set-owner-trust
 
         AnyCardHasNullPin   = 0x0080,
-        AnyCardCanLearnKeys = 0x0100,
 
         MustBeRoot          = 0x0200,
         MustBeTrustedRoot   = 0x0400 | MustBeRoot,
@@ -84,7 +83,7 @@ public:
      *
      * @returns null QString on success. Error message otherwise.
      */
-    static QList<Command *> commandsForFiles(const QStringList &files);
+    static QList<Command *> commandsForFiles(const QStringList &files, KeyListController *controller);
 
     /** Get a command for a query.
      *
