@@ -73,6 +73,11 @@ public:
     explicit Private(KeyToCardCommand *qq, const std::string &slot, const std::string &serialNumber, const std::string &appName);
 
 private:
+    enum Confirmation {
+        AskForConfirmation,
+        SkipConfirmation,
+    };
+
     void start();
 
     void startKeyToOpenPGPCard();
@@ -90,11 +95,13 @@ private:
     void updateDone();
 
     void keyHasBeenCopiedToCard();
-    bool backupKey();
+    void backupHasBeenCreated(const QString &backupFilename);
+
+    QString backupKey();
     std::vector<QByteArray> readSecretKeyFile();
     bool writeSecretKeyBackup(const QString &filename, const std::vector<QByteArray> &keydata);
 
-    void startDeleteSecretKeyLocally();
+    void startDeleteSecretKeyLocally(Confirmation confirmation);
     void deleteSecretKeyLocallyFinished(const GpgME::Error &err);
 
 private:
@@ -298,7 +305,7 @@ void KeyToCardCommand::Private::startKeyToOpenPGPCard()
     }
 
     // Now do the deed
-    const auto time = QDateTime::fromSecsSinceEpoch(quint32(subkey.creationTime()), Qt::UTC);
+    const auto time = QDateTime::fromSecsSinceEpoch(quint32(subkey.creationTime()), QTimeZone::utc());
     const auto timestamp = time.toString(QStringLiteral("yyyyMMdd'T'HHmmss"));
     const QString cmd = QStringLiteral("KEYTOCARD --force %1 %2 %3 %4")
                             .arg(QString::fromLatin1(subkey.keyGrip()), QString::fromStdString(serialNumber()), QString::fromStdString(cardSlot), timestamp);
@@ -481,22 +488,45 @@ void KeyToCardCommand::Private::keyHasBeenCopiedToCard()
     const auto answer = KMessageBox::questionTwoActionsCancel(parentWidgetOrView(),
                                                               xi18nc("@info",
                                                                      "<para>The key has been copied to the card.</para>"
-                                                                     "<para>Do you want to delete the copy of the key stored on this computer?</para>"),
+                                                                     "<para>You can now delete the copy of the key stored on this computer. "
+                                                                     "Optionally, you can first create a backup of the key.</para>"),
                                                               i18nc("@title:window", "Success"),
-                                                              KGuiItem{i18nc("@action:button", "Create Backup and Delete Key")},
-                                                              KGuiItem{i18nc("@action:button", "Delete Key")},
-                                                              KGuiItem{i18nc("@action:button", "Keep Key")});
-    if (answer == KMessageBox::ButtonCode::Cancel) {
-        finished();
-        return;
-    }
+                                                              KGuiItem{i18nc("@action:button", "Create backup")},
+                                                              KGuiItem{i18nc("@action:button", "Delete copy on disk")},
+                                                              KGuiItem{i18nc("@action:button", "Keep copy on disk")});
     if (answer == KMessageBox::ButtonCode::PrimaryAction) {
-        if (!backupKey()) {
-            finished();
-            return;
+        const QString backupFilename = backupKey();
+        if (backupFilename.isEmpty()) {
+            // user canceled the backup or there was an error; repeat above question
+            QMetaObject::invokeMethod(q, [this]() {
+                keyHasBeenCopiedToCard();
+            });
         }
+        backupHasBeenCreated(backupFilename);
+    } else if (answer == KMessageBox::ButtonCode::SecondaryAction) {
+        startDeleteSecretKeyLocally(AskForConfirmation);
+    } else {
+        finished();
+    }
+}
+
+void KeyToCardCommand::Private::backupHasBeenCreated(const QString &backupFilename)
+{
+    const auto answer =
+        KMessageBox::questionTwoActions(parentWidgetOrView(),
+                                        xi18nc("@info",
+                                               "<para>The key has been copied to the card and a backup has been written to <filename>%1</filename>.</para>"
+                                               "<para>Do you want to delete the copy of the key stored on this computer?</para>",
+                                               backupFilename),
+                                        i18nc("@title:window", "Success"),
+                                        KGuiItem{i18nc("@action:button", "Delete copy on disk")},
+                                        KGuiItem{i18nc("@action:button", "Keep copy on disk")});
+    if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+        // the user has created a backup; don't ask again for confirmation before deleting the copy on disk
+        startDeleteSecretKeyLocally(SkipConfirmation);
+    } else {
+        finished();
     }
-    startDeleteSecretKeyLocally();
 }
 
 namespace
@@ -517,7 +547,7 @@ QString proposeFilename(const Subkey &subkey)
     }
     const auto shortKeyID = Formatting::prettyKeyID(key.shortKeyID());
     const auto shortSubkeyID = Formatting::prettyKeyID(QByteArray{subkey.keyID()}.right(8).constData());
-    const auto usage = Formatting::usageString(subkey).replace(QLatin1String{", "}, QLatin1String{"_"});
+    const auto usage = Formatting::usageString(subkey).replace(QLatin1StringView{", "}, QLatin1String{"_"});
     /* Not translated so it's better to use in tutorials etc. */
     filename = ((shortKeyID == shortSubkeyID) //
                     ? QStringView{u"%1_%2_SECRET_KEY_BACKUP_%3"}.arg(name, shortKeyID, usage)
@@ -533,7 +563,7 @@ QString requestPrivateKeyBackupFilename(const QString &proposedFilename, QWidget
                                                   i18nc("@title:window", "Backup Secret Key"),
                                                   QStringLiteral("imp"),
                                                   proposedFilename,
-                                                  i18nc("description of filename filter", "Secret Key Backup Files") + QLatin1String{" (*.gpgsk)"});
+                                                  i18nc("description of filename filter", "Secret Key Backup Files") + QLatin1StringView{" (*.gpgsk)"});
 
     if (!filename.isEmpty()) {
         const QFileInfo fi{filename};
@@ -547,17 +577,17 @@ QString requestPrivateKeyBackupFilename(const QString &proposedFilename, QWidget
 }
 }
 
-bool KeyToCardCommand::Private::backupKey()
+QString KeyToCardCommand::Private::backupKey()
 {
     static const QByteArray backupInfoName = "Backup-info:";
 
     auto keydata = readSecretKeyFile();
     if (keydata.empty()) {
-        return false;
+        return {};
     }
     const auto filename = requestPrivateKeyBackupFilename(proposeFilename(subkey), parentWidgetOrView());
     if (filename.isEmpty()) {
-        return false;
+        return {};
     }
 
     // remove old backup info
@@ -574,12 +604,16 @@ bool KeyToCardCommand::Private::backupKey()
     };
     keydata.insert(keydata.begin(), backupInfo.join(' ') + '\n');
 
-    return writeSecretKeyBackup(filename, keydata);
+    if (writeSecretKeyBackup(filename, keydata)) {
+        return filename;
+    } else {
+        return {};
+    }
 }
 
 std::vector<QByteArray> KeyToCardCommand::Private::readSecretKeyFile()
 {
-    const auto filename = QString::fromLatin1(subkey.keyGrip()) + QLatin1String{".key"};
+    const auto filename = QString::fromLatin1(subkey.keyGrip()) + QLatin1StringView{".key"};
     const auto path = QDir{Kleo::gnupgPrivateKeysDirectory()}.filePath(filename);
 
     QFile file{path};
@@ -616,7 +650,7 @@ bool KeyToCardCommand::Private::writeSecretKeyBackup(const QString &filename, co
     return true;
 }
 
-void KeyToCardCommand::Private::startDeleteSecretKeyLocally()
+void KeyToCardCommand::Private::startDeleteSecretKeyLocally(Confirmation confirmation)
 {
     const auto card = SmartCard::ReaderStatus::instance()->getCard(serialNumber(), appName);
     if (!card) {
@@ -625,16 +659,18 @@ void KeyToCardCommand::Private::startDeleteSecretKeyLocally()
         return;
     }
 
-    const auto answer = KMessageBox::questionTwoActions(parentWidgetOrView(),
-                                                        xi18n("Do you really want to delete the local copy of the secret key?"),
-                                                        i18nc("@title:window", "Confirm Deletion"),
-                                                        KStandardGuiItem::del(),
-                                                        KStandardGuiItem::cancel(),
-                                                        {},
-                                                        KMessageBox::Notify | KMessageBox::Dangerous);
-    if (answer != KMessageBox::ButtonCode::PrimaryAction) {
-        finished();
-        return;
+    if (confirmation == AskForConfirmation) {
+        const auto answer = KMessageBox::questionTwoActions(parentWidgetOrView(),
+                                                            xi18nc("@info", "Do you really want to delete the copy of the key stored on this computer?"),
+                                                            i18nc("@title:window", "Confirm Deletion"),
+                                                            KStandardGuiItem::del(),
+                                                            KStandardGuiItem::cancel(),
+                                                            {},
+                                                            KMessageBox::Notify | KMessageBox::Dangerous);
+        if (answer != KMessageBox::ButtonCode::PrimaryAction) {
+            finished();
+            return;
+        }
     }
 
     const auto cmd = QByteArray{"DELETE_KEY --force "} + subkey.keyGrip();
@@ -646,10 +682,12 @@ void KeyToCardCommand::Private::startDeleteSecretKeyLocally()
 void KeyToCardCommand::Private::deleteSecretKeyLocallyFinished(const GpgME::Error &err)
 {
     if (err) {
-        error(xi18nc("@info", "<para>Failed to delete the key:</para><para><message>%1</message></para>", Formatting::errorAsString(err)));
+        error(xi18nc("@info",
+                     "<para>Failed to delete the copy of the key stored on this computer:</para><para><message>%1</message></para>",
+                     Formatting::errorAsString(err)));
     }
     ReaderStatus::mutableInstance()->updateStatus();
-    success(i18nc("@info", "Successfully copied the key to the card."));
+    success(i18nc("@info", "Successfully deleted the copy of the key stored on this computer."));
     finished();
 }
 
